yakumo.nova.v2.fixed_ip.Manager

Package yakumo :: Package nova :: Package v2 :: Module fixed_ip :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for fixed IPs in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for fixed IPs in Compute API v2

Instance Methods | [hide private]
str |
get(self, ip=None) Get information for fixed IP | source code
None |
reserve(self, ip=None) Reserve a fixed IP | source code
None |
unreserve(self, ip=None) Release a fixed IP | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``ip``'``,` `'````'``,` <yakumo.mapper.NoopClass object at`...``
| _hidden_methods = ``[``'``create``'``,` `'``list``'``,` `'``update``'``]``
| _id_attr = ``'``ip``'``
| _json_resource_key = ``'``fixed_ip``'``
| _url_resource_path = ``'``/os-fixed-ips``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get(self, ip=None) | source code
Get information for fixed IP Parameters: `ip` (str) - Fixed IP (required) Returns: str Information of the fixed IP Overrides: base.Manager.get

### reserve(self, ip=None) | source code
Reserve a fixed IP Parameters: `ip` (str) - Fixed IP (required) Returns: None

### unreserve(self, ip=None) | source code
Release a fixed IP Parameters: `ip` (str) - Fixed IP (required) Returns: None

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('ip', '', <yakumo.mapper.NoopClass object at 0x7f133076f290>)]